@@ -1,3 +1,3 @@
 from brparser.beatmapparser import (BeatmapOsu, HitCircleOsu, SliderOsu,
     SpinnerOsu, apply_mods_to_time, apply_mods_to_diff, diff_range)
-from brparser.replayparser import Replay, ReplayPath, Key, Keypress
+from brparser.replayparser import Replay, ReplayPath, Key, Keypress, Mod
